==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ExtendedHashMutableDirectedGraph.h <==
// class soot.jimple.toolkits.annotation.arraycheck.ExtendedHashMutableDirectedGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a53370fea72712d0 soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph
// @dep_class b22bed2885652868 soot_toolkits_graph_HashMutableDirectedGraph

// header file dependencies
// @dep_header soot_toolkits_graph_HashMutableDirectedGraph

#include "soot/toolkits/graph/HashMutableDirectedGraph.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$addEdge$690d34df2a2949f2(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$addMutualEdge$55e3e832b6dc720d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$mergeWith$a2b4a011a743a44e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$skipNode$7a453b4cafbed850(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$addEdge$690d34df2a2949f2;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$addMutualEdge$55e3e832b6dc720d;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$mergeWith$a2b4a011a743a44e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$skipNode$7a453b4cafbed850;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods {
	void	(*addEdge$690d34df2a2949f2)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*addMutualEdge$55e3e832b6dc720d)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*mergeWith$a2b4a011a743a44e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *);
	void	(*skipNode$7a453b4cafbed850)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_HashMutableDirectedGraph$vmethods	soot_toolkits_graph_HashMutableDirectedGraph;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods	soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_refs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_nonrefs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ExtendedHashMutableDirectedGraph.h <==
// class soot.jimple.toolkits.annotation.arraycheck.ExtendedHashMutableDirectedGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a53370fea72712d0 soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph
// @dep_class b22bed2885652868 soot_toolkits_graph_HashMutableDirectedGraph

// header file dependencies
// @dep_header soot_toolkits_graph_HashMutableDirectedGraph

#include "soot/toolkits/graph/HashMutableDirectedGraph.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$addEdge$690d34df2a2949f2(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$addMutualEdge$55e3e832b6dc720d(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$mergeWith$a2b4a011a743a44e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$skipNode$7a453b4cafbed850(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$addEdge$690d34df2a2949f2;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$addMutualEdge$55e3e832b6dc720d;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$mergeWith$a2b4a011a743a44e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$skipNode$7a453b4cafbed850;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods {
	void	(*addEdge$690d34df2a2949f2)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*addMutualEdge$55e3e832b6dc720d)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*mergeWith$a2b4a011a743a44e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *) _JC_JCNI_ATTR;
	void	(*skipNode$7a453b4cafbed850)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_HashMutableDirectedGraph$vmethods	soot_toolkits_graph_HashMutableDirectedGraph;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vmethods	soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_refs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_nonrefs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ExtendedHashMutableDirectedGraph_H_ */
